==> xl-react-components-0.18.103.tgz: package/app/xl-react-form/xl-react-dip-redux-form/xl-react-dip-redux-form-actions.js <==
const GROUP_PROPERTIES = '@xl-react-dip-redux-form/GROUP_PROPERTIES';
const INITIALIZE = '@xl-react-dip-redux-form/INITIALIZE';
const MERGE_CONTEXT = '@xl-react-dip-redux-form/MERGE_CONTEXT';
const OPEN_CATEGORY_GROUP = '@xl-react-dip-redux-form/OPEN_CATEGORY_GROUP';
const SET_CONTEXT = '@xl-react-dip-redux-form/SET_CONTEXT';
const TOGGLE_CATEGORY_GROUP = '@xl-react-dip-redux-form/TOGGLE_CATEGORY_GROUP';
const UNMOUNT = '@xl-react-dip-redux-form/UNMOUNT';
const UPDATE_EXTERNAL_PROPERTIES = '@xl-react-dip-redux-form/UPDATE_EXTERNAL_PROPERTIES';
const CHANGE_PRISTINE_STATE = '@xl-react-dip-redux-form/CHANGE_PRISTINE_STATE';
const CHANGE_VALIDITY = '@xl-react-dip-redux-form/CHANGE_VALIDITY';

export default {
    CHANGE_PRISTINE_STATE,
    CHANGE_VALIDITY,
    changePristineState: (formId, pristinity) => ({formId, pristinity, type: CHANGE_PRISTINE_STATE}),
    changeValidity: (formId, validity) => ({formId, type: CHANGE_VALIDITY, validity}),
    GROUP_PROPERTIES,
    groupProperties: (formId, collapsed) => ({collapsed, formId, type: GROUP_PROPERTIES}),
    INITIALIZE,
    initialize: ({formId, ...rest}) => ({formId, rest, type: INITIALIZE}),
    MERGE_CONTEXT,
    mergeContext: (formId, context) => ({context, formId, type: MERGE_CONTEXT}),
    OPEN_CATEGORY_GROUP,
    openCategoryGroup: (formId, categoryName) => ({categoryName, formId, type: OPEN_CATEGORY_GROUP}),
    SET_CONTEXT,
    setContext: (formId, context) => ({context, formId, type: MERGE_CONTEXT}),
    TOGGLE_CATEGORY_GROUP,
    toggleCategoryGroup: (formId, categoryName) => ({categoryName, formId, type: TOGGLE_CATEGORY_GROUP}),
    UNMOUNT,
    unmount: (formId) => ({formId, type: UNMOUNT}),
    UPDATE_EXTERNAL_PROPERTIES,
    updateExternalProperties: (formId, externalProperties) => ({
        externalProperties,
        formId,
        type: UPDATE_EXTERNAL_PROPERTIES
    })
};

==> xl-react-components-0.21.15.tgz: package/app/xl-react-form/xl-react-dip-redux-form/xl-react-dip-redux-form-actions.js <==
const GROUP_PROPERTIES = '@xl-react-dip-redux-form/GROUP_PROPERTIES';
const INITIALIZE = '@xl-react-dip-redux-form/INITIALIZE';
const MERGE_CONTEXT = '@xl-react-dip-redux-form/MERGE_CONTEXT';
const OPEN_CATEGORY_GROUP = '@xl-react-dip-redux-form/OPEN_CATEGORY_GROUP';
const SET_CONTEXT = '@xl-react-dip-redux-form/SET_CONTEXT';
const TOGGLE_CATEGORY_GROUP = '@xl-react-dip-redux-form/TOGGLE_CATEGORY_GROUP';
const UNMOUNT = '@xl-react-dip-redux-form/UNMOUNT';
const UPDATE_EXTERNAL_PROPERTIES = '@xl-react-dip-redux-form/UPDATE_EXTERNAL_PROPERTIES';
const CHANGE_PRISTINE_STATE = '@xl-react-dip-redux-form/CHANGE_PRISTINE_STATE';
const CHANGE_VALIDITY = '@xl-react-dip-redux-form/CHANGE_VALIDITY';
const REMOVE_VALIDATION_MESSAGES = '@xl-react-dip-redux-form/REMOVE_VALIDATION_MESSAGES';

export default {
    CHANGE_PRISTINE_STATE,
    CHANGE_VALIDITY,
    changePristineState: (formId, pristinity) => ({formId, pristinity, type: CHANGE_PRISTINE_STATE}),
    changeValidity: (formId, validity) => ({formId, type: CHANGE_VALIDITY, validity}),
    GROUP_PROPERTIES,
    groupProperties: (formId, collapsed) => ({collapsed, formId, type: GROUP_PROPERTIES}),
    INITIALIZE,
    initialize: ({formId, ...rest}) => ({formId, rest, type: INITIALIZE}),
    MERGE_CONTEXT,
    mergeContext: (formId, context) => ({context, formId, type: MERGE_CONTEXT}),
    OPEN_CATEGORY_GROUP,
    openCategoryGroup: (formId, categoryName) => ({categoryName, formId, type: OPEN_CATEGORY_GROUP}),
    REMOVE_VALIDATION_MESSAGES,
    removeValidationMessages: (formId, propertyNames) => ({formId, propertyNames, type: REMOVE_VALIDATION_MESSAGES}),
    SET_CONTEXT,
    setContext: (formId, context) => ({context, formId, type: MERGE_CONTEXT}),
    TOGGLE_CATEGORY_GROUP,
    toggleCategoryGroup: (formId, categoryName) => ({categoryName, formId, type: TOGGLE_CATEGORY_GROUP}),
    UNMOUNT,
    unmount: (formId) => ({formId, type: UNMOUNT}),
    UPDATE_EXTERNAL_PROPERTIES,
    updateExternalProperties: (formId, model) => ({
        formId,
        model,
        type: UPDATE_EXTERNAL_PROPERTIES
    })
};
